# TGLFNN-UKAEA

JAX implementation of the UKAEA TGLF surrogate. Different versions of the
surrogate exist, including a *multi-machine* version and a *spherical tokamak*
version.

Weights, normalisations, config files and compiled models are stored at
[ukaea/tglfnn-ukaea](https://github.com/ukaea/tglfnn-ukaea).